@@ -23,9 +23,14 @@ class BlueprintLibraryMenuItem(MenuItemHook):
     def render(self, request):
         if request.user.has_perm("blueprints.basic_access"):
             if request.user.has_perm("blueprints.manage_requests"):
-                app_count = Request.objects.requests_fulfillable_by_user(
-                    request.user
-                ).count()
+                app_count = (
+                    Request.objects.all()
+                    .requests_fulfillable_by_user(request.user)
+                    .count()
+                    + Request.objects.all()
+                    .requests_being_fulfilled_by_user(request.user)
+                    .count()
+                )
             else:
                 app_count = None
             self.count = app_count if app_count and app_count > 0 else None
